@@ -15,6 +15,7 @@ from .measurement_import import Measurement
 from .ptw_import import PTWMultimporter
 from .sim_import import Simulation
 from .egs_import import EGSSimulation
+from .RangeSlider import RangeSliderH
 
 
 class DoseFigureHandler:
@@ -30,6 +31,7 @@ class DoseFigureHandler:
         self.errlimmax = 1.1
         self.errorbars = True
         self.caxcorrection = False
+        self.xaxisname = None
         self.diffplot = False
         self.zoom = self.parent.zoom.get()
         self.half = self.parent.half.get()
@@ -454,14 +456,22 @@ class DoseFigureHandler:
         directions = [plot.direction for plot in self.plots]
         if directions.count(directions[0]) == len(directions):
 
-            xlabel = f"{directions[0]}-{self.text.axis[self.lang]} [mm]"
+            self.xlabel = f"{directions[0]}-{self.text.axis[self.lang]} [mm]"
         else:
-            xlabel = f"X- {self.text.orr[self.lang]} Y-{self.text.axis[self.lang]}"
+            self.xlabel = (
+                f"X- {self.text.orr[self.lang]} Y-{self.text.axis[self.lang]} [mm]"
+            )
 
         if self.diffplot == True:
-            self.diffax.set_xlabel(xlabel, size=12)
+            if self.xaxisname != None:
+                self.diffax.set_xlabel(self.xaxisname, size=12)
+            else:
+                self.diffax.set_xlabel(self.xlabel, size=12)
         else:
-            self.ax.set_xlabel(xlabel, size=12)
+            if self.xaxisname != None:
+                self.ax.set_xlabel(self.xaxisname, size=12)
+            else:
+                self.ax.set_xlabel(self.xlabel, size=12)
         if self.norm == False:
             self.ax.set_ylabel(self.plots[0].unit, size=12)
 
@@ -504,17 +514,7 @@ class DoseFigureHandler:
         except:
             pass
 
-        self.axlims = (self.parent.axlims.get(), self.parent.axlims.get())
-        if self.plots[0].direction == "Z" or self.half == True:
-            self.axlims = (0, self.axlims[1])
-        self.ax.set_xlim(
-            left=self.ax.get_xlim()[0] - self.axlims[0],
-            right=self.ax.get_xlim()[1] + self.axlims[1],
-        )
-        self.ax.set_xbound(
-            lower=self.ax.get_xlim()[0] - self.axlims[0],
-            upper=self.ax.get_xlim()[1] + self.axlims[1],
-        )
+        self.set_xlims()
 
         if self.zoom == True:
 
@@ -630,6 +630,22 @@ class DoseFigureHandler:
 
         return
 
+    def set_xlims(self):
+
+        if self.parent.current_limits == []:
+            self.current_limits = [self.ax.get_xlim()[0], self.ax.get_xlim()[1]]
+            self.parent.current_limits = self.current_limits
+            self.parent.initial_limits = self.current_limits
+            self.parent.slidervars[0].set(self.current_limits[0])
+            self.parent.slidervars[1].set(self.current_limits[1])
+
+        self.current_limits = [
+            self.parent.slidervars[0].get(),
+            self.parent.slidervars[1].get(),
+        ]
+
+        self.ax.set_xlim(self.current_limits)
+
     def return_figure(self, filenames):
 
         """Passes the image of the plot and the plot type to the MainApplication
@@ -657,6 +673,11 @@ class DoseFigureHandler:
         self.add_legend()
         self.ax.set_aspect("auto")
         self.set_style()
+        if self.half == True:
+
+            xlim_r = [plots.axis[self.half] for plots in self.plots]
+            xlim_r = max([item for sublist in xlim_r for item in sublist])
+            self.ax.set_xlim(0, xlim_r)
 
         self.canvas.draw()
         buffer = self.canvas.buffer_rgba()
